@@ -19,11 +19,9 @@
 
 #include "test_frequentrequests.h"
 
-#include <libkvkontakte/userinfofulljob.h>
+#include "userinfojob.h"
 
-#include <qtest_kde.h>
-
-#include <QtCore/QList>
+#include <QtTest/QtTest>
 
 using namespace Vkontakte;
 
@@ -34,20 +32,19 @@ TestFrequentRequests::TestFrequentRequests()
 
 void TestFrequentRequests::initTestCase()
 {
-    authenticate();
+    authenticate(Vkontakte::AppPermissions::NoPermissions);
 }
 
-void TestFrequentRequests::testUserInfoFullJob()
+void TestFrequentRequests::testUserInfoJob()
 {
     // Send 20 requests without delays
     for (int i = 0; i < 20; ++i)
     {
-        Vkontakte::UserInfoFullJob* const job = new Vkontakte::UserInfoFullJob(
-            accessToken(), 1, true, true);
+        Vkontakte::UserInfoJob* const job = new Vkontakte::UserInfoJob(
+            accessToken(), 1);
         job->exec();
         QVERIFY(!job->error());
     }
 }
 
-QTEST_KDEMAIN(TestFrequentRequests, GUI)
-#include "test_frequentrequests.moc"
+QTEST_MAIN(TestFrequentRequests)
