@@ -19,7 +19,7 @@
 
 #include "test_friends.h"
 
-#include <libkvkontakte/friendlistjob.h>
+#include "friendlistjob.h"
 
 #include <qtest_kde.h>
 
@@ -46,3 +46,4 @@ void TestFriends::testFriendListJob()
 }
 
 QTEST_KDEMAIN(TestFriends, GUI)
+#include "test_friends.h"
