@@ -25,13 +25,12 @@
 #include <QtCore/QObject>
 
 namespace KIPIVkontaktePlugin {
-    class VkAPI;
+    class VkApi;
 }
 
 /*
  * What is tested here:
  *   class UserInfoJob
- *   class UserInfoFullJob
  */
 class TestUserInfo : public VkTestBase
 {
@@ -45,7 +44,6 @@ private Q_SLOTS:
 
     void testUserInfoJob();
     void testSelfUserInfoJob();
-    void testUserInfoFullJob();
 };
 
 #endif // TEST_USERINFO_H
