@@ -18,6 +18,7 @@
  */
 
 #include "vktestbase.h"
+
 #include "vkapi.h"
 
 #include <QtCore/QEventLoop>
@@ -28,7 +29,7 @@
 #define VK_APP_ID   "2446321"
 
 VkTestBase::VkTestBase()
-    : m_vkapi(0)
+    : m_vkapi(new Vkontakte::VkApi(0))
 {
 }
 
@@ -42,7 +43,7 @@ VkTestBase::~VkTestBase()
 
 QString VkTestBase::getSavedToken() const
 {
-    QFile file(AUTOTESTS_API_TOKEN_PATH);
+    QFile file(QStringLiteral(AUTOTESTS_API_TOKEN_PATH));
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
     {
         return QString();
@@ -53,10 +54,10 @@ QString VkTestBase::getSavedToken() const
     return line.trimmed();
 }
 
-void VkTestBase::authenticate()
+void VkTestBase::authenticate(Vkontakte::AppPermissions::Value permissions)
 {
-    m_vkapi = new KIPIVkontaktePlugin::VkAPI(0);
-    m_vkapi->setAppId(VK_APP_ID); // TODO: library should better not crash if setAppId is not called
+    m_vkapi->setAppId(QStringLiteral(VK_APP_ID)); // TODO: library should better not crash if setAppId is not called
+    m_vkapi->setRequiredPermissions(permissions);
 
     QString token = getSavedToken();
     if (!token.isEmpty())
@@ -79,5 +80,3 @@ QString VkTestBase::accessToken() const
 {
     return m_vkapi->accessToken();
 }
-
-#include "vktestbase.moc"
