@@ -20,11 +20,13 @@
 #ifndef VKTESTBASE_H
 #define VKTESTBASE_H
 
+#include "apppermissions.h"
+
 #include <QtCore/QObject>
 #include <QtCore/QVector>
 
-namespace KIPIVkontaktePlugin {
-    class VkAPI;
+namespace Vkontakte {
+    class VkApi;
 }
 
 class VkTestBase : public QObject
@@ -33,16 +35,16 @@ class VkTestBase : public QObject
 
 public:
     VkTestBase();
-    ~VkTestBase();
+    virtual ~VkTestBase();
 
 protected:
-    void authenticate();
+    void authenticate(Vkontakte::AppPermissions::Value permissions);
     QString accessToken() const;
 
 private:
     QString getSavedToken() const;
 
-    KIPIVkontaktePlugin::VkAPI *m_vkapi;
+    Vkontakte::VkApi *m_vkapi;
 };
 
 #endif // VKTESTBASE_H
